import { OTLPHttpJsonTraceExporter, registerOTel } from "@vercel/otel";
import { EXPORT_URL, HIGHLIGHT_PROJECT_ID } from "./consts";
export function vercelOtelRegister({ serviceName }) {
    return function register() {
        registerOTel({
            serviceName,
            instrumentationConfig: {
                fetch: {
                    propagateContextUrls: [
                        "*"
                    ]
                }
            },
            traceExporter: new OTLPHttpJsonTraceExporter({
                url: EXPORT_URL
            }),
            attributes: {
                "highlight.project_id": HIGHLIGHT_PROJECT_ID,
                "highlight.source": "backend"
            },
            attributesFromHeaders: (headers, getter)=>{
                const highlightHeader = getter.get(headers, "x-highlight-request");
                const matchedHeader = parseHighlightFromUnknown(highlightHeader, HEADER_REGEX);
                if (matchedHeader) return matchedHeader;
                const highlightCookie = getter.get(headers, "cookie");
                const matchedCookie = parseHighlightFromUnknown(highlightCookie, COOKIE_REGEX);
                if (matchedCookie) return matchedCookie;
                return undefined;
            }
        });
    };
}
const COOKIE_REGEX = /sessionSecureID\s*=\s*(?<sessionId>\w+)\/(?<traceId>\w+)\s*;/;
const HEADER_REGEX = /\s*(?<sessionId>\w+)\/(?<traceId>\w+)\s*/;
function parseHighlightFromUnknown(input, regex) {
    if (typeof input !== "string") return;
    const match = input.match(regex);
    if (!match) return;
    const { sessionId, traceId } = match.groups ?? {};
    if (typeof sessionId !== "string" || typeof traceId !== "string") return;
    return {
        "highlight.session_id": sessionId,
        "highlight.trace_id": traceId
    };
}
